Struct Shared
Source pub struct Shared<'a> { }
A buffer many threads write into at once, each to elements no other thread touches.
Borrows buf for the lifetime of the Shared.
Writes v at i.
Safety
No other thread may read or write element i while this Shared is alive.
Panics
If i is out of bounds.
Reads element i.
Safety
No other thread may write element i while this Shared is alive.
Panics
If i is out of bounds.
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The alignment of pointer.
The type for initializers.
Initializes a with the given initializer.
Read more
Mutably dereferences the given pointer.
Read more
Drops the object pointed to by the given pointer.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.