pub struct QMatrix {
pub rows: usize,
pub k: usize,
pub q: Vec<i8>,
pub scale: Vec<f32>,
}Expand description
A matrix rounded to INT8 row by row, in the layout of the module docs.
Fields
rows: usizeRows.
k: usizeValues per row.
q: Vec<i8>[rows.div_ceil(8)][k.div_ceil(8)][4][2][8].
scale: Vec<f32>max |row| / 127 for each row, so a row is its values times its scale.
Implementations